==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fempty_trash-1.2-1.2.2.tar.gz: empty_trash/functions.php <==
<?php
/*
   Empty Trash - A Plugin for SqurrelMail
   Version: 1.2
   Version Date: 04-Jul-2003
   Author: Derek Battams <derek@battams.ca>
   Please see the README file for further information

   File: setup.php

DATE          AUTHOR   CHANGE
=============================================================================
17-Apr-2002   ddb      Completion of original version
03-Nov-2002   ddb      Bug fixes; audit for SM >= 1.2.8 compatibility
04-Jul-2003   pl       New setup.php format for faster overall SM performance
                       Updated for SM version reporting API

*/


// Increment a counter each time a user signs into SM 
function incCounter_do()
{
   global $data_dir, $username;

   $logins = getPref($data_dir, $username, 'logins');
   setPref($data_dir, $username, 'logins', ++$logins);
   setPref($data_dir, $username, 'doEmpty', 1);
}

// Delete a user's trash folder.  Use JavaScript to redirect a user to the SM
// empty_trash script, which does the dirty work for us.
function delTrash()
{
   echo "<script language=\"javaScript\">\n";
   echo "window.location=\"empty_trash.php\"\n";
   echo "</script>\n";
}

// Given a date, calculate the week number of the year, using the ISO method.
//
// Though this is available from the date() function, it's only available in 
// PHP >= 4.1.0.  At the time I'm writing this I'm not using 4.1.0 so I've wrote
// it myself (with some help from the web, of course)!
function isoWeekNum($yr, $mth, $day)
{
   $j = julianDay($yr, $mth, $day);
   $x = ($j + 31741 - ($j % 7)) % 146097 % 36524 % 1461;
   $y = (int) ($x / 1460);
   $z = (($x - $y) % 365) + $y;
   $weekNum = (int) ($z / 7 + 1);
   if($weekNum == 1 && $mth != 1)
      return 53;
   if($weekNum >= 52 && $mth != 12)
      return 1;
   return (int) ($z / 7 + 1);
}

// Given a date, calculate the Julian Day value, which is used in the ISO week
// number calculation.
function julianDay($yr, $mth, $day)
{
   $a = floor((14-$mth) / 12);
   $y = $yr + 4800 - $a;
   $m = $mth + 12 * $a - 3;

   return $day + floor((153*$m+2)/5) + (365*$y) + floor($y/4) - floor($y/100) + floor($y/400) - 32045;
}

// Decide if it's time to delete the user's trash folder and if it is then do
// it!  In this version of the plugin, a user's trash folder is deleted under
// any of the following circumstances:
//
// * Every 10th login
// * Once a week
function do_delete_do()
{
global $data_dir, $username;

   $yr = date("Y");
   $mth = date("m");
   $day = date("d");
   $curWeek = isoWeekNum($yr, $mth, $day);

   $lastDel = getPref($data_dir, $username, 'lastDel');
   if($lastDel == '')
      $lastDel = $yr * 100 + $curWeek;

   $lastDelWk = $lastDel % 100;
   $lastDelYr = ($lastDel - $lastDelWk) / 100;
   $doEmpty = getPref($data_dir, $username, 'doEmpty');
   $logins = getPref($data_dir, $username, 'logins');

   if($doEmpty && (!($logins % 10) || ($lastDelYr < $yr || $lastDelWk < $curWeek)))
   {
      setPref($data_dir, $username, 'doEmpty', 0);
      $lastDel = date("Y") * 100 + $curWeek;
      setPref($data_dir, $username, 'lastDel', $lastDel);
      delTrash();
   }
}

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fempty_trash-1.3-1.2.2.tar.gz: empty_trash/functions.php <==
<?php

/*
   Empty Trash - A Plugin for SqurrelMail
   Version: 1.3
   Version Date: 29-Jun-2004
   Authors: Derek Battams <derek@battams.ca>
            Paul Lesneiwski <pdontthink@angrynerds.com>

   Please see the README file for further information

   File: setup.php

DATE          AUTHOR   CHANGE
=============================================================================
17-Apr-2002   ddb      Completion of original version
03-Nov-2002   ddb      Bug fixes; audit for SM >= 1.2.8 compatibility
04-Jul-2003   pl       New setup.php format for faster overall SM performance
                       Updated for SM version reporting API
29-Jun-2004   pl       Created config file to allow administrative control over
                       deletion criteria.
                       Fixed time-based criteria to measure days instead of weeks
                       (which had an inadvertent bug)

*/


// Increment a counter each time a user signs into SM 
function incCounter_do()
{
   global $data_dir, $username;

   $logins = getPref($data_dir, $username, 'logins');
   setPref($data_dir, $username, 'logins', ++$logins);
   setPref($data_dir, $username, 'doEmpty', 1);
}

// Delete a user's trash folder.  Use JavaScript to redirect a user to the SM
// empty_trash script, which does the dirty work for us.
function delTrash()
{
   echo "<script language=\"javaScript\">\n";
   echo "window.location=\"empty_trash.php\"\n";
   echo "</script>\n";
}

// Decide if it's time to delete the user's trash folder and if it is then do
// it!  In this version of the plugin, a user's trash folder is deleted under
// any of the following circumstances:
//
function do_delete_do()
{
global $data_dir, $username;

   if (defined('SM_PATH'))
      include_once(SM_PATH . 'plugins/empty_trash/config.php');
   else
      include_once('../plugins/empty_trash/config.php');

   $now = time();
 
   $lastDel = getPref($data_dir, $username, 'lastDel');
   if($lastDel == '')
      $lastDel = $now;

   $sec_in_a_day = 60*60*24;
   $diff = $now - $lastDel;
   for ($daysDiff = 0; $diff >= $sec_in_a_day; $diff -= $sec_in_a_day)
      $daysDiff++; 

   $doEmpty = getPref($data_dir, $username, 'doEmpty');
   $logins = getPref($data_dir, $username, 'logins');

   global $loginLimit, $dayLimit;
   $overLoginLimit = ($loginLimit > 0 && ($logins % $loginLimit) === 0);
   $overDayLimit = ($dayLimit > 0 && $daysDiff > $dayLimit);

   if($doEmpty && ($overLoginLimit || $overDayLimit))
   {
      setPref($data_dir, $username, 'doEmpty', 0);
      $lastDel = time();
      setPref($data_dir, $username, 'lastDel', $lastDel);
      delTrash();
   }
}

?>
